==> cejs-4.5.4.tgz: package/application/locale/resources/nl-NL.js <==
/*	Localized messages of CeL.
	This file is auto created by auto-generate tool: build.nodejs(.js) @ 2022.
*/'use strict';typeof CeL==='function'&&CeL.application.locale.gettext.set_text({
	"untranslated message count": "1000+",
	"\u5730\u7406\u5ea7\u6a19\uff1a": "Co\u00f6rdinaten: ",
	"\u7d93\u5ea6\uff1a": "Breedtegraad: ",
	"\u7def\u5ea6\uff1a": "Lengtegraad: ",
	"\u524d\u7db4": "voorvoegsel",
	"\u6642\u5340\uff1a": "Tijdzone: ",
	"\u8acb\u6ce8\u610f\uff1a\u672c\u6b04\u50c5\u4f9b\u958b\u767c\u4eba\u54e1\u4f7f\u7528\u3002": "WAARSCHUWING: Alleen voor ontwikkelaars.",
	"Loading...": "Bezig met laden\u2026",
	"\u9664\u53bb\u6b64\u6b04": "Kolom verwijderen",
	"\u589e\u52a0\u6b64\u6b04": "Kolom toevoegen",
	"general data layer": "algemeen",
	"\u6240\u6709\u570b\u5bb6": "Alle landen",
	"France": "Frankrijk",
	"Great Britain": "Groot Brittani\u00eb",
	"Spain": "Spanje",
	"\u51fa\u751f": "Geboren",
	"\u901d\u4e16": "Overleden",
	"\u52a0\u5195": "Kroning",
	"\u524d\u4efb": "Voorganger",
	"\u7e7c\u4efb": "Opvolger",
	"\u7236\u89aa": "Vader",
	"\u6bcd\u89aa": "Moeder",
	"\u914d\u5076": "Echtgenoot",
	"Initializing...": "Initialiseren...",
	"Aries": "Ram",
	"Taurus": "Stier",
	"Gemini": "Tweelingen",
	"Cancer": "Kreeft",
	"Leo": "Leeuw",
	"Virgo": "Maagd",
	"Libra": "Weegschaal",
	"Scorpio": "Schorpioen",
	"Sagittarius": "Boogschutter",
	"Capricorn": "Steenbok",
	"Aquarius": "Waterman",
	"Pisces": "Vissen",
	"Unix time": "Unix tijd",
	"\u6714": "nieuwe maan",
	"\u66d9\u66ae\u5149": "schemering",
	"calendar": "kalender",
	"Gregorian calendar": "Gregoriaanse kalender",
	"Julian calendar": "Juliaanse kalender",
	"finished": "voltooid",
	"No changes.": "Geen wijzigingen.",
	"\u4e0a\u5f26": "eerste kwartier",
	"\u671b": "volle maan",
	"\u4e0b\u5f26": "laatste kwartier",
	"sunrise": "zonsopkomst",
	"sunset": "zonsondergang",
	"Language": "Taal",
	"No reason provided": "Geen reden opgegeven",
	"\u8abf\u964d\u53d6\u5f97\u9801\u9762\u7684\u4e0a\u9650\uff0c\u6539\u6210\u6bcf\u6b21\u6700\u591a %1 \u500b\u9801\u9762\u3002": "Beperk het maximumaantal pagina's per keer tot %1 pagina's.",
	"Unknown API response: %1": "Onbekend api-antwoord: %1",
	"no change": "geen wijzigingen",
	"function": "functie",
	"number": "getal",
	"Move %1 to %2 failed: %3": "Verplaatsing %1 naar %2 mislukt: %3",
	"Contents": "Inhoud",
	"Italy": "Itali\u00eb",
	"Poland": "Polen",
	"Luxembourg": "Luxemburg",
	"Netherlands": "Nederland",
	"Bavaria": "Beieren",
	"Austria": "Oosterrijk",
	"Switzerland": "Zwitserland",
	"Hungary": "Hongarije",
	"Germany": "Duitsland",
	"Norway": "Noorwegen",
	"Denmark": "Denemarken",
	"Sweden": "Zweden",
	"Finland": "Finland",
	"Bulgaria": "Bulgarije",
	"Soviet Union": "Sovjet-Unie",
	"Serbia": "Servi\u00eb",
	"Romania": "Roemeni\u00eb",
	"Greece": "Griekenland",
	"T\u00fcrkiye": "Turkije",
	"Egypt": "Egypte",
	"now": "zojuist",
	"several seconds ago": "enkele seconden geleden",
	"soon": "zodadelijk",
	"%1 {{PLURAL:%1|second|seconds}} ago": "%1 seconde{{PLURAL:%1||n}} geleden",
	"%1 {{PLURAL:%1|minute|minutes}} ago": "%1 {{PLURAL:%1|minuut|minuten}} geleden",
	"%1 {{PLURAL:%1|hour|hours}} ago": "%1 uur{{PLURAL:%1|}} geleden",
	"%1 {{PLURAL:%1|day|days}} ago": "%1 dag{{PLURAL:%1||en}} geleden",
	"%1 {{PLURAL:%1|week|weeks}} ago": "%1 {{PLURAL:%1|week|weken}} geleden",
	"Invalid date: %1": "Ongeldige datum: %1",
	"\u8a3b": "Opmerking",
	"British": "Brits",
	"\u2191Back to TOC": "\u2191Terug naar inhoudsopgave",
	"expand": "uitvouwen",
	"collapse": "samenvouwen",
	"\u8a9e\u8a00\u6578": "Aantal talen",
	"\u5e73\u5747": "Gemiddelde",
	"\u5408\u8a08": "Som",
	"\u689d\u76ee\u4e00\u89bd": "Artikellijst",
	"See also": "Zie ook",
	"\u7121\u6a19\u7c64": "Geen label"
},
"nl-NL");

==> cejs-4.5.8.tgz: package/application/locale/resources/nl-NL.js <==
/*	Localized messages of CeL.
	This file is auto created by auto-generate tool: build.nodejs(.js) @ 2024.
*/'use strict';typeof CeL==='function'&&CeL.application.locale.gettext.set_text({
	"untranslated message count": "1000+",
	"\u5730\u7406\u5ea7\u6a19\uff1a": "Co\u00f6rdinaten: ",
	"\u7def\u5ea6\uff1a": "Breedtegraad: ",
	"\u7d93\u5ea6\uff1a": "Lengtegraad: ",
	"\u524d\u7db4": "voorvoegsel",
	"\u6642\u5340\uff1a": "Tijdzone: ",
	"\u8acb\u6ce8\u610f\uff1a\u672c\u6b04\u50c5\u4f9b\u958b\u767c\u4eba\u54e1\u4f7f\u7528\u3002": "WAARSCHUWING: Alleen voor ontwikkelaars.",
	"Loading...": "Bezig met laden\u2026",
	"\u9664\u53bb\u6b64\u6b04": "Kolom verwijderen",
	"\u589e\u52a0\u6b64\u6b04": "Kolom toevoegen",
	"general data layer": "algemeen",
	"\u6240\u6709\u570b\u5bb6": "Alle landen",
	"France": "Frankrijk",
	"Great Britain": "Groot Brittani\u00eb",
	"Spain": "Spanje",
	"\u51fa\u751f": "Geboren",
	"\u901d\u4e16": "Overleden",
	"\u52a0\u5195": "Kroning",
	"\u524d\u4efb": "Voorganger",
	"\u7e7c\u4efb": "Opvolger",
	"\u7236\u89aa": "Vader",
	"\u6bcd\u89aa": "Moeder",
	"\u914d\u5076": "Echtgenoot",
	"Initializing...": "Initialiseren...",
	"Aries": "Ram",
	"Taurus": "Stier",
	"Gemini": "Tweelingen",
	"Cancer": "Kreeft",
	"Leo": "Leeuw",
	"Virgo": "Maagd",
	"Libra": "Weegschaal",
	"Scorpio": "Schorpioen",
	"Sagittarius": "Boogschutter",
	"Capricorn": "Steenbok",
	"Aquarius": "Waterman",
	"Pisces": "Vissen",
	"Unix time": "Unix tijd",
	"\u6714": "nieuwe maan",
	"\u66d9\u66ae\u5149": "schemering",
	"calendar": "kalender",
	"Gregorian calendar": "Gregoriaanse kalender",
	"Julian calendar": "Juliaanse kalender",
	"finished": "voltooid",
	"No changes.": "Geen wijzigingen.",
	"No page modified": "Geen pagina aangepast",
	"\u4e0a\u5f26": "eerste kwartier",
	"\u671b": "volle maan",
	"\u4e0b\u5f26": "laatste kwartier",
	"sunrise": "zonsopkomst",
	"sunset": "zonsondergang",
	"Language": "Taal",
	"No reason provided": "Geen reden opgegeven",
	"Get configurations from page %1": "Configuraties ophalen van pagina %1",
	"\u8abf\u964d\u53d6\u5f97\u9801\u9762\u7684\u4e0a\u9650\uff0c\u6539\u6210\u6bcf\u6b21\u6700\u591a %1 \u500b\u9801\u9762\u3002": "Beperk het maximumaantal pagina's per keer tot %1 pagina's.",
	"Unknown API response: %1": "Onbekend api-antwoord: %1",
	"no change": "geen wijzigingen",
	"No user name or password provided. The login attempt was abandoned.": "Geen gebruikersnaam of wachtwoord opgegeven. De aanmeldpoging is afgebroken.",
	"function": "functie",
	"number": "getal",
	"Move %1 to %2 failed: %3": "Verplaatsing %1 naar %2 mislukt: %3",
	"Contents": "Inhoud",
	"Italy": "Itali\u00eb",
	"Poland": "Polen",
	"Luxembourg": "Luxemburg",
	"Netherlands": "Nederland",
	"Bavaria": "Beieren",
	"Austria": "Oosterrijk",
	"Switzerland": "Zwitserland",
	"Hungary": "Hongarije",
	"Germany": "Duitsland",
	"Norway": "Noorwegen",
	"Denmark": "Denemarken",
	"Sweden": "Zweden",
	"Finland": "Finland",
	"Bulgaria": "Bulgarije",
	"Soviet Union": "Sovjet-Unie",
	"Serbia": "Servi\u00eb",
	"Romania": "Roemeni\u00eb",
	"Greece": "Griekenland",
	"T\u00fcrkiye": "Turkije",
	"Egypt": "Egypte",
	"now": "zojuist",
	"several seconds ago": "enkele seconden geleden",
	"soon": "zodadelijk",
	"%1 {{PLURAL:%1|second|seconds}} ago": "%1 seconde{{PLURAL:%1||n}} geleden",
	"%1 {{PLURAL:%1|minute|minutes}} ago": "%1 {{PLURAL:%1|minuut|minuten}} geleden",
	"%1 {{PLURAL:%1|hour|hours}} ago": "%1 uur{{PLURAL:%1|}} geleden",
	"%1 {{PLURAL:%1|day|days}} ago": "%1 dag{{PLURAL:%1||en}} geleden",
	"%1 {{PLURAL:%1|week|weeks}} ago": "%1 {{PLURAL:%1|week|weken}} geleden",
	"Invalid date: %1": "Ongeldige datum: %1",
	"\u8a3b": "Opmerking",
	"British": "Brits",
	"\u2191Back to TOC": "\u2191Terug naar inhoudsopgave",
	"expand": "uitvouwen",
	"collapse": "samenvouwen",
	"Duplicate task name %1! Will overwrite old task with new task: %2\u2192%3": "Dubbele taaknaam %1! De oude taak wordt overschreven door de nieuwe: %2\u2192%3",
	"\u672c\u7ae0\u7bc0\u672a\u8a2d\u5b9a\u4efb\u52d9\u5167\u5bb9: %1": "De sectie stelt de taakconfiguratie niet in: %1",
	"%1 {{PLURAL:%1|page|pages}} modified": "%1 {{PLURAL:%1|pagina|pagina's}} bewerkt",
	"Remove %1 non-defunct {{PLURAL:%1|anchor|anchors}}": "%1 nog bestaande {{PLURAL:%1|anker|ankers}} verwijderen",
	"\u8a9e\u8a00\u6578": "Aantal talen",
	"\u5e73\u5747": "Gemiddelde",
	"\u5408\u8a08": "Som",
	"\u689d\u76ee\u4e00\u89bd": "Artikellijst",
	"See also": "Zie ook",
	"\u7121\u6a19\u7c64": "Geen label"
},
"nl-NL");
